==> kt-ds-core-dev-0.0.11.tar.gz: kt-ds-core-dev-0.0.11/setup.py <==
#
#   Copyright 2020 The SpaceONE Authors.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


from setuptools import setup, find_packages

with open('VERSION', 'r') as f:
    VERSION = f.read().strip()
    f.close()

setup(
    name='kt-ds-core-dev',
    version=VERSION,
    description='SpaceONE core library',
    long_description='',
    url='https://www.spaceone.dev/',
    author='MEGAZONE SpaceONE Team',
    author_email='admin@spaceone.dev',
    license='Apache License 2.0',
    packages=find_packages(),
    install_requires=[
        # 'grpcio',
        'protobuf==3.*',
        'grpcio-reflection',
        'google-interface-core',
        'grpcio-health-checking',
        'asyncio',
        'PyYAML',
        'unittest-xml-reporting>=3.0.0',
        'pycryptodome',
        # 'pycryptodome==3.8.2',
        'schedule',
        'cachetools',
        'jwcrypto',
        'python-jose',
        # 'jwcrypto==0.7',
        # 'python-jose==3.1.0',
        'factory-boy',
        'jsonschema',
        'python-dateutil',
        'python-consul',
        'scheduler-cron',
        'click',
        'celery[redis]==4.4.7',
        'uvicorn',
        'fastapi',
        'fastapi-utils==0.2.1',
        'python-consul',
        'dnspython',
        'typing-inspect'
    ],
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'spaceone = spaceone.core.command:cli',
        ]
    },
)

==> kt-ds-core-dev-0.0.12.tar.gz: kt-ds-core-dev-0.0.12/setup.py <==
#
#   Copyright 2020 The SpaceONE Authors.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.


from setuptools import setup, find_packages

with open('VERSION', 'r') as f:
    VERSION = f.read().strip()
    f.close()

setup(
    name='kt-ds-core-dev',
    version=VERSION,
    description='SpaceONE core library',
    long_description='',
    url='https://www.spaceone.dev/',
    author='MEGAZONE SpaceONE Team',
    author_email='admin@spaceone.dev',
    license='Apache License 2.0',
    packages=find_packages(),
    install_requires=[
        # 'grpcio',
        'protobuf==3.*',
        'grpcio-reflection',
        # 'google-interface-core',
        'grpcio-health-checking',
        'asyncio',
        'PyYAML',
        'unittest-xml-reporting>=3.0.0',
        'pycryptodome',
        # 'pycryptodome==3.8.2',
        'schedule',
        'cachetools',
        'jwcrypto',
        'python-jose',
        # 'jwcrypto==0.7',
        # 'python-jose==3.1.0',
        'factory-boy',
        'jsonschema',
        'python-dateutil',
        'python-consul',
        'scheduler-cron',
        'click',
        'celery[redis]==4.4.7',
        'uvicorn',
        'fastapi',
        'fastapi-utils==0.2.1',
        'python-consul',
        'dnspython',
        'typing-inspect',
        'google-api-core'
    ],
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'spaceone = spaceone.core.command:cli',
        ]
    },
)
